*********************************************
:mod:`mopidy.audio.mixers.nad` -- NAD mixer
*********************************************

.. automodule:: mopidy.audio.mixers.nad
    :synopsis: Mixer element for controlling volume on NAD amplifiers
